#!/bin/bash
# (c) Copyright 2007-2014 Hewlett Packard Development Company, L.P.
# Version A.12.00.00

############################################################################################################### 
# REVISION HISTORY 
# A.04.02.02   10/19/2012    1) Added code changes to support online toolkit package modification 
# A.12.00.00   11/29/2013    1) Removed toolkit MAINTANANCE MODE and legacy style package support
#                            2) Added code for SG online modification failure check
############################################################################################################### 

###########################
# Source utility functions.
###########################

 . /etc/cmcluster.conf
if [[ -z $SG_UTILS ]]; then
        SG_UTILS=$SGCONF/scripts/mscripts/utils.sh
fi

if [[ -f ${SG_UTILS} ]]; then
    . ${SG_UTILS}
    if (( $? != 0 ))
    then
        echo "ERROR: Unable to source package utility functions file: ${SG_UTILS}"
        exit 1
    fi
else
    echo "ERROR: Unable to find package utility functions file: ${SG_UTILS}"
    exit 1
fi

###################################################################
#
# Get the environment for this package through utility function
# sg_source_pkg_env().
#
###################################################################
export PATH=$PATH:$SGSBIN

sg_source_pkg_env $*

##################################################################
#
#       VALIDATE FUNCTION
#
#################################################################

function validate_function
{
        sg_log 0 "MySQL Toolkit validation"

	if [[ -z $MYSQL_CONFIGURATION_FILE_PATH ]]; then
		sg_log 0 "Define CONFIGURATION_FILE_PATH"
		exit 1
	fi
	
}

#############################################################
#
#       START FUNCTION
#
############################################################

function start_function
{
   # Checks to see if this is online addition of new module

   if sg_check_if_reconfig_has_failed ; then
      sg_log 999 "WARNING: Not attempting to start the newly added MySQL toolkit module"
      return  
   fi
 
   ${TKIT_SCRIPT_DIR}/toolkit.sh start
   exit_code=$?
   if sg_check_if_it_is_reconfiguration ; then
     if [[  $exit_code -ne 0 ]]; then
       sg_log 999 "ERROR: Failed to start the newly added MySQL toolkit module"
       sg_set_reconfig_failure
     else
       sg_log 999 "SUCCESS: Successfully started newly added MySQL toolkit module"
       sg_log 0 "SUCCESS: Successfully started newly added MySQL toolkit module"
     fi
   fi
 
}

#############################################################
#
#       STOP FUNCTION
#
############################################################

function stop_function
{

         ${TKIT_SCRIPT_DIR}/toolkit.sh stop
        exit_code=$?

}

#############################################################
#
#       MONITOR FUNCTION
#
############################################################

function monitor_function
{
         ${TKIT_SCRIPT_DIR}/toolkit.sh monitor
        exit_code=$?
}

#############################################################
#
#       RECONFIGURE STOP FUNCTION
#
############################################################

function  reconfigure_stop_function
{
       if sg_check_if_reconfig_has_failed
       then
          sg_log 999 "WARNING: Not attempting to stop the mysql service $SERVICE_TO_RESTART for online package modification."
          return
       fi
       if ! $SGSBIN/cmhaltserv $SERVICE_TO_RESTART ; then
          sg_log 999 "ERROR: Could not stop  the service $SERVICE_TO_RESTART for online package modification."
          sg_set_reconfig_failure 
          exit_code=1
       else
          sg_log 999 "SUCCESS: Successfully stopped  the service $SERVICE_TO_RESTART for online package modification."
          sg_log 0 "SUCCESS: Successfully stopped  the service $SERVICE_TO_RESTART for online package modification."
       fi
}

#############################################################
#
#       RECONFIGURE START FUNCTION
#
############################################################

function reconfigure_start_function
{
        msg="cmrunserv: Unable to start service $SERVICE_TO_RESTART (it is already active)"
        out=`$SGSBIN/cmrunserv $SERVICE_TO_RESTART "$SERVICE_CMD_TO_RESTART" 2>&1`
        exit_code=$?
        if [[ $exit_code -ne 0 ]] && [[ "$msg" != "$out" ]] ; then
            sg_log 999 "ERROR: Failed to start the service $SERVICE_TO_RESTART after online package modification"
            sg_set_reconfig_failure 
        elif [[ $exit_code -eq 0 ]] ; then
            sg_log 999 "SUCCESS: Successfully started the service $SERVICE_TO_RESTART for online package modification."
            if ! sg_check_if_reconfig_has_failed ; then
                 sg_log 0 "SUCCESS: Succesfully started service $SERVICE_TO_RESTART for online package modification. "
            fi
        fi
}

##################################
#
#Start of Routines
#
#################################

typeset -i exit_code=0

export TKIT_SCRIPT_DIR=$SGROOT/mysqltoolkit
export CONFIGURATION_FILE_PATH=$MYSQL_CONFIGURATION_FILE_PATH
export PID_FILE=$MYSQL_PID_FILE
export RETRY_TIMES=$MYSQL_RETRY_TIMES
export MONITOR_INTERVAL=$MYSQL_MONITOR_INTERVAL
export TIME_OUT=$MYSQL_TIME_OUT


#Identify the Toolkit service name and corresponding service command for the MySQL package
if [[ $1 = "reconfigure_stop" || $1 = "reconfigure_start" ]]; then
 if [[ ${#SG_SERVICE_CMD[@]} -ne 0 ]]; then
       b=0
       SERVICE_TO_RESTART=""
       SERVICE_CMD_TO_RESTART=""
       for i in "${SG_SERVICE_CMD[@]}"
       do
	    echo "$i"|grep "mysql_monitor" >> /dev/null
	    if [[ $? -eq 0 ]]; then
		 SERVICE_TO_RESTART=${SG_SERVICE_NAME[$b]}
		 SERVICE_CMD_TO_RESTART="$i"
		 break		
	   fi
           (( b = $b + 1 ))
      done
  fi 
fi

case $1 in
        validate)
                validate_function
                ;;
        start)
                start_function
                ;;
        stop)
                stop_function
                ;;
        mysql_monitor)
                monitor_function
                ;;
	reconfigure_stop)
		reconfigure_stop_function
		;;
	reconfigure_start)
		reconfigure_start_function
		;;
	
        *)
                sg_log 0 "Usage: ${0} [ start | stop | mysql_monitor | validate | reconfigure_stop | reconfigure_start ]"
                ;;
esac

exit $exit_code

